local mod = ...



-- Default Balancing (event list) ---------------------------------------------------------------------------------------------

mod:overrideAsset({
    Id = "DEFAULT_BALANCING",
    EventList = {
        Action = "APPEND",
        "EVENT_MARKETCART_START",
    }
})



-- Event: Market Carts ---------------------------------------------------------------------------------------------
mod:registerAsset({
	DataType = "EVENT",
    Id = "EVENT_MARKETCART_START",
    IsInMainPool = false, -- the main pool seems to suppress itself until the first Weather event fires, so custom events should be outside the main pool
    IsRecurrent = false,
    DaysBetweenOccurences = nil,
    DaysToFirst = 1,
    Delay = 10,
	ConditionList = {
		{
            DataType = "EVENT_CONDITION_BUILDING_BUILT",
            AssetBuilding = "MONUMENT_MARKET"
		}
	},
	ActionList = {
        {
            DataType = "EVENT_ACTION_GIVE_QUEST",
            Quest = "QUEST_MARKETCART_BERRY"
        },
    }
})



-- Quest: Berry ---------------------------------------------------------------------------------------------
mod:registerAsset({
    DataType = "QUEST",
    Id = "QUEST_MARKETCART_BERRY",
    Name = "QUEST_MARKETCART_BERRY_NAME",
    Description = "QUEST_MARKETCART_BERRY_DESC",
    IsSilent = true,
	QuestFunction = {
        DataType = "QUEST_FUNCTION_CONTAINER",
        QuestContainerDescription = "",
        SubQuestList = {
            {
                DataType = "QUEST_FUNCTION_BUILD", 
                BuildingListToBuild = {
                    "BUILDING_GATHERING_CAMP"
                }
            },
            {  
                DataType = "QUEST_FUNCTION_ASSIGN_RESOURCE_MARKET",
                Resource = "BERRIES"
            },
        }
    },
    QuestRewardActionList = {
        {
            DataType = "QUEST_REWARD_UNLOCK_BUILDING_LIST",
            UnlockName = "UNLOCK_MARKETCART_BERRY"
        },
    },
    QuestFailActionList = nil,
    QuestListToUnlockAfter = nil,
    OnFailCallback = nil,
    OnSuccessCallback = nil
})



-- If Fuel is loaded, add the fuelmonger cart
if (foundation.isModLoaded("7b6dabf2-3523-46ff-ba47-caca86189784")) then

    -- Event 
    mod:overrideAsset({
        Id = "DEFAULT_BALANCING",
        EventList = {
            Action = "APPEND",
            "EVENT_MARKETCART_FUEL",
        }
    })

    mod:registerAsset({
        DataType = "EVENT",
        Id = "EVENT_MARKETCART_FUEL",
        IsInMainPool = false, -- the main pool seems to suppress itself until the first Weather event fires, so custom events should be outside the main pool
        IsRecurrent = false,
        DaysBetweenOccurences = nil,
        DaysToFirst = 1,
        Delay = 10, 
        ConditionList = {
            {
                DataType = "EVENT_CONDITION_BUILDING_BUILT",
                AssetBuilding = "MONUMENT_MARKET"
            }
        },
        ActionList = {
            {
                DataType = "EVENT_ACTION_GIVE_QUEST",
                Quest = "QUEST_MARKETCART_FUELMONGER"
            },
        }
    })
        
    -- Quest
    mod:registerAsset({
        DataType = "QUEST",
        Id = "QUEST_MARKETCART_FUELMONGER",
        Name = "QUEST_MARKETCART_FUELMONGER_NAME",
        Description = "QUEST_MARKETCART_FUELMONGER_DESC",
        IsSilent = true,
        QuestFunction = {
            DataType = "QUEST_FUNCTION_BUILD", 
            BuildingListToBuild = {
                "FUELCART"
            }
        },
        QuestRewardActionList = {
            {
                DataType = "QUEST_REWARD_UNLOCK_BUILDING_LIST",
                UnlockName = "UNLOCK_MARKETCART_FUELMONGER"
            },
        },
        QuestFailActionList = nil,
        QuestListToUnlockAfter = nil,
        OnFailCallback = nil,
        OnSuccessCallback = nil
    })
end



-- If Security is loaded, add the Town Crier
if (foundation.isModLoaded("99ee3b3b-f103-41f0-a725-bc466a2fc6de")) then

    -- Event 
    mod:overrideAsset({
        Id = "DEFAULT_BALANCING",
        EventList = {
            Action = "APPEND",
            "EVENT_MARKETCART_TOWNCRIER",
        }
    })

    mod:registerAsset({
        DataType = "EVENT",
        Id = "EVENT_MARKETCART_TOWNCRIER",
        IsInMainPool = false, -- the main pool seems to suppress itself until the first Weather event fires, so custom events should be outside the main pool
        IsRecurrent = false,
        DaysBetweenOccurences = nil,
        DaysToFirst = 1,
        Delay = 10, 
        ConditionList = {
            {
                DataType = "EVENT_CONDITION_BUILDING_BUILT",
                AssetBuilding = "MONUMENT_MARKET"
            }
        },
        ActionList = {
            {
                DataType = "EVENT_ACTION_GIVE_QUEST",
                Quest = "QUEST_MARKETCART_TOWNCRIER"
            },
        }
    })
    
    -- Quest
    mod:registerAsset({
        DataType = "QUEST",
        Id = "QUEST_MARKETCART_TOWNCRIER",
        Name = "QUEST_MARKETCART_TOWNCRIER_NAME",
        Description = "QUEST_MARKETCART_TOWNCRIER_DESC",
        IsSilent = true,
        QuestFunction = {
            DataType = "QUEST_FUNCTION_BUILD", 
            BuildingListToBuild = {
                "BUILDING_SECURITY_SECURITY"
            }
        },
        QuestRewardActionList = {
            {
                DataType = "QUEST_REWARD_UNLOCK_BUILDING_LIST",
                UnlockName = "UNLOCK_MARKETCART_TOWNCRIER"
            },
        },
        QuestFailActionList = nil,
        QuestListToUnlockAfter = nil,
        OnFailCallback = nil,
        OnSuccessCallback = nil
    })

end








